TtlInspectable

Trait TtlInspectable 

pub trait TtlInspectable: Backend {
    // Required method
    fn ttl<'life0, 'life1, 'async_trait>(
        &'life0 self,
        key: &'life1 str,
    ) -> Pin<Box<dyn Future<Output = Result<Option<Duration>, BackendError>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;

    // Provided method
    fn refresh_ttl<'life0, 'life1, 'async_trait>(
        &'life0 self,
        _key: &'life1 str,
        _ttl: Duration,
    ) -> Pin<Box<dyn Future<Output = Result<bool, BackendError>> + Send + 'async_trait>>
       where Self: Sync + 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait { ... }
}
Optional extension for backends that can report the remaining TTL of a key.

Required Methods

fn ttl<'life0, 'life1, 'async_trait>( &'life0 self, key: &'life1 str, ) -> Pin<Box<dyn Future<Output = Result<Option<Duration>, BackendError>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Return the remaining TTL for key, or None if the key does not exist or has no expiry.

Provided Methods

fn refresh_ttl<'life0, 'life1, 'async_trait>( &'life0 self, _key: &'life1 str, _ttl: Duration, ) -> Pin<Box<dyn Future<Output = Result<bool, BackendError>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Refresh the TTL on an existing key. Default: not supported.

Implementors