SecureCache

Struct SecureCache 

pub struct SecureCache<'a> { /* private fields */ }
Encrypted cache handle returned by CacheKit::secure().

All values are serialized, then encrypted with AES-256-GCM before storage. L1 stores ciphertext to maintain zero-knowledge guarantees.

Implementations

Source

impl SecureCache<'_>

pub async fn set<T: Serialize>( &self, key: &str, value: &T, ) -> Result<(), CachekitError>

Encrypt and store value under key using the client’s default TTL.

pub async fn set_with_ttl<T: Serialize>( &self, key: &str, value: &T, ttl: Duration, ) -> Result<(), CachekitError>

Encrypt and store value under key with an explicit ttl.

pub async fn get<T: DeserializeOwned>( &self, key: &str, ) -> Result<Option<T>, CachekitError>

Retrieve, decrypt, and deserialize a value stored under key.

Checks L1 (which holds ciphertext) before the backend.

pub async fn delete(&self, key: &str) -> Result<bool, CachekitError>

Delete an encrypted key. Behaves identically to CacheKit::delete.

pub async fn exists(&self, key: &str) -> Result<bool, CachekitError>

Check if an encrypted key exists. Behaves identically to CacheKit::exists.