Pluggable cache backend trait and implementations (CachekitIO, Redis, Workers).
Modules
- cachekitio
- HTTP backend for the cachekit.io SaaS API.
Structs
- Health
Status - Describes the health of a backend at a point in time.
Traits
- Backend
- Async cache backend abstraction.
- Lockable
Backend - Optional extension for backends that support distributed locking.
- TtlInspectable
- Optional extension for backends that can report the remaining TTL of a key.